/*
# ---------------------------------------------------------------------
#
# Copyright (c) CREATIS (Centre de Recherche en Acquisition et Traitement de l'Image 
#                        pour la Santé)
# Authors : Eduardo Davila, Frederic Cervenansky, Claire Mouton
#
#  This software is governed by the CeCILL-B license under French law and 
#  abiding by the rules of distribution of free software. You can  use, 
#  modify and/ or redistribute the software under the terms of the CeCILL-B 
#  license as circulated by CEA, CNRS and INRIA at the following URL 
#  http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html 
#  or in the file LICENSE.txt.
#
#  As a counterpart to the access to the source code and  rights to copy,
#  modify and redistribute granted by the license, users are provided only
#  with a limited warranty  and the software's author,  the holder of the
#  economic rights,  and the successive licensors  have only  limited
#  liability. 
#
#  The fact that you are presently reading this means that you have had
#  knowledge of the CeCILL-B license and that you accept its terms.
# ------------------------------------------------------------------------  
*/

/*=========================================================================                                                                               
Program:   bbtk
Module:    $RCSfile$
Language:  C++
Date:      $Date$
Version:   $Revision$
=========================================================================*/

/* ---------------------------------------------------------------------

* Copyright (c) CREATIS-LRMN (Centre de Recherche en Imagerie Medicale)
* Authors : Eduardo Davila, Laurent Guigues, Jean-Pierre Roux
*
*  This software is governed by the CeCILL-B license under French law and 
*  abiding by the rules of distribution of free software. You can  use, 
*  modify and/ or redistribute the software under the terms of the CeCILL-B 
*  license as circulated by CEA, CNRS and INRIA at the following URL 
*  http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html 
*  or in the file LICENSE.txt.
*
*  As a counterpart to the access to the source code and  rights to copy,
*  modify and redistribute granted by the license, users are provided only
*  with a limited warranty  and the software's author,  the holder of the
*  economic rights,  and the successive licensors  have only  limited
*  liability. 
*
*  The fact that you are presently reading this means that you have had
*  knowledge of the CeCILL-B license and that you accept its terms.
* ------------------------------------------------------------------------ */                                                                         


/****
* Design and Developpement of BBTK GEditor
* Ricardo A Corredor J <ra.corredor67@uniandes.edu.co>
* RaC - 2010
****/

#ifndef __GConnectorModel_h__
#define __GConnectorModel_h__

//Includes same project
#include "GlobalConstants.h"
#include "GObjectModel.h"
#include "GPortModel.h"

//Includes creaMaracasVisu
#include <manualContourModel.h>

//Includes std
#include <iostream>


namespace bbtk
{

	class GConnectorModel : public GObjectModel 
	{

	public: 

		//Constructors
		GConnectorModel();
		~GConnectorModel();
		
		//Public methods

		// Sets the start port of the connection that will be used in the manualContourModel
		void setStartPort(GPortModel* startPort);

		// Sets the end port in the BBTKGEditor connector model and also in the contour model
		void setEndPort(GPortModel* endPort);

		// Assigns the creaMaracasVisu model
		void setManualContourModel(manualContourModel* model);
		manualContourModel* getManualContourModel();

		GPortModel* getStartPort();
		GPortModel* getEndPort();		

		// Refresh the position of the contourModel first and last points with the data of the connector model
		void updateStartEndPoints();

		// Set the ports as NO connected
		void disconnectConnection();

		virtual void save(std::string &content);
		
	private:

		//Private Attributes

		GPortModel* _startPort;
		GPortModel* _endPort;

		manualContourModel* _model;

		//Private Methods

	protected:

		//Protected Attributes

		//Protected methods
		
	};


}
// namespace bbtk
#endif

